@@ -3,7 +3,7 @@ from pathlib import Path
 
 from albion_similog.log import setup_logger
 from albion_similog.prepare_data import read_and_prepare_data
-from albion_similog.well_correlation import WellCorrelation
+from albion_similog.well_correlation import compute_markers, WellCorrelation
 
 
 logger = setup_logger(__name__)
@@ -49,11 +49,17 @@ def run(data, outputdir, experiment=None):
         depth_min=10,
         depth_max=200,
         min_seg=1,
-        pelt_sup=0.2,
+        nb_markers=10,
         lr_normalize=True,
         segmentize_with_pelt=False,
     )
     algo_corr.run()
+    markers = compute_markers(
+        algo_corr.consensus_depth,
+        algo_corr.depth_match_global,
+        algo_corr.consensus,
+        "MD",
+    )
     logger.info("Save the results...")
     suffix = ""
     if experiment is not None:
@@ -61,7 +67,7 @@ def run(data, outputdir, experiment=None):
     consensus_batch_filepath = outputdir / ("consensus_batch" + suffix + ".csv")
     algo_corr.consensus.to_csv(consensus_batch_filepath)
     tops_unsupervised_filepath = outputdir / ("tops_unsupervised" + suffix + ".csv")
-    algo_corr.markers.to_csv(tops_unsupervised_filepath, index=False)
+    markers.to_csv(tops_unsupervised_filepath, index=False)
     logger.info("End of the procedure.")
 
 
