@@ -408,7 +408,9 @@ class WellCorrelation:
                 "100",
                 str(self._sequence_filepath),
                 str(self._famsa_output_filepath),
-            ]
+            ],
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
         )
         # Import alignment
         self._multi_sequence_alignment = read(
@@ -423,6 +425,7 @@ class WellCorrelation:
         class initialization
 
         """
+        df_list = []
         # Set depth match global for each well
         for key, data in self._dict_data_original.items():
             # Extract DNA sequences as strings for each well
@@ -445,10 +448,12 @@ class WellCorrelation:
             # Recover segmentation indices that match aligned sequence indices
             seg_match = self._segmentation_indices[key][df_align["indices"]]
             # Build depth_match_global item starting from raw data
-            cur_df = pd.DataFrame(
-                {"hole_id": key, "from": data.iloc[seg_match].index.values}
+            df_list.append(
+                pd.DataFrame(
+                    {"hole_id": key, "from": data.iloc[seg_match].index.values}
+                )
             )
-            self.depth_match_global = pd.concat([self.depth_match_global, cur_df])
+        self.depth_match_global = pd.concat(df_list)
 
     def compute_consensus(self):
         """Compute the consensus log, which is a "mean" log that aggregates the logs from every well. This
@@ -527,8 +532,8 @@ def compute_markers(tops, df_aligned_depths, consensus, depth_column):
     aligned_positions = consensus.loc[consensus[depth_column].isin(tops)][
         "global_index"
     ]
+    df_list = []
     # Finding the consensus marker for each well
-    markers = pd.DataFrame({"hole_id": [], "from": [], "to": [], "code": []})
     for key, group in df_aligned_depths.groupby("hole_id"):
         tops_current = group.iloc[aligned_positions].copy().reset_index(drop=True)
         if tops_current.shape[0] == 0:
@@ -546,6 +551,8 @@ def compute_markers(tops, df_aligned_depths, consensus, depth_column):
         # Fill in the resulting marker dataframe
         tops_current["to"] = tops_current["from"] + 0.1
         tops_current = tops_current.loc[tops_current.truncate(begidx, endidx).index]
-        markers = pd.concat([markers, tops_current.reset_index()])
+        df_list.append(tops_current.reset_index())
+    markers = pd.concat(df_list)
+    markers = markers[["hole_id", "from", "to", "code"]]
     markers["code"] = markers["code"].astype(int)
     return markers
